=== modified file 'commit.py'
--- commit.py	2007-10-30 22:23:37 +0000
+++ commit.py	2007-11-02 22:08:54 +0000
@@ -111,6 +111,7 @@
         #       It used to set all changes but this one to False
         self._selected = selected
         self._enable_per_file_commits = True
+        self._commit_all_changes = True
         self.committed_revision_id = None # Nothing has been committed yet
 
         self.setup_params()
@@ -361,10 +362,18 @@
             None, _("Commit all changes"))
         self._files_box.pack_start(self._commit_all_files_radio, expand=False)
         self._commit_all_files_radio.show()
+        self._commit_all_files_radio.connect('toggled',
+            self._toggle_commit_selection)
         self._commit_selected_radio = gtk.RadioButton(
             self._commit_all_files_radio, _("Only commit selected changes"))
         self._files_box.pack_start(self._commit_selected_radio, expand=False)
         self._commit_selected_radio.show()
+        self._commit_selected_radio.connect('toggled',
+            self._toggle_commit_selection)
+        if self._pending:
+            self._commit_all_files_radio.set_label(_('Commit all changes*'))
+            self._commit_all_files_radio.set_sensitive(False)
+            self._commit_selected_radio.set_sensitive(False)
 
         scroller = gtk.ScrolledWindow()
         scroller.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -398,8 +407,9 @@
             name = _('Commit*')
         else:
             name = _('Commit')
-        self._treeview_files.append_column(gtk.TreeViewColumn(name,
-                                           crt, active=2))
+        commit_col = gtk.TreeViewColumn(name, crt, active=2)
+        commit_col.set_visible(False)
+        self._treeview_files.append_column(commit_col)
         self._treeview_files.append_column(gtk.TreeViewColumn(_('Path'),
                                            gtk.CellRendererText(), text=3))
         self._treeview_files.append_column(gtk.TreeViewColumn(_('Type'),
@@ -415,6 +425,18 @@
         else:
             model[path][2] = not model[path][2]
 
+    def _toggle_commit_selection(self, button):
+        all_files = self._commit_all_files_radio.get_active()
+        if self._commit_all_changes != all_files:
+            checked_col = self._treeview_files.get_column(0)
+            self._commit_all_changes = all_files
+            if all_files:
+                checked_col.set_visible(False)
+            else:
+                checked_col.set_visible(True)
+            renderer = checked_col.get_cell_renderers()[0]
+            renderer.set_property('activatable', not all_files)
+
     def _construct_pending_list(self):
         # Pending information defaults to hidden, we put it all in 1 box, so
         # that we can show/hide all of them at once
@@ -594,7 +616,7 @@
 
         file_info = []
         for record in records:
-            if record[2]:           # [2] checkbox
+            if self._commit_all_changes or record[2]:# [2] checkbox
                 file_id = record[0] # [0] file_id
                 path = record[1]    # [1] real path
                 file_message = record[5] # [5] commit message

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2007-10-30 21:58:07 +0000
+++ tests/test_commit.py	2007-11-02 22:08:54 +0000
@@ -210,6 +210,11 @@
         renderer = commit_col.get_cell_renderers()[0]
         self.assertTrue(renderer.get_property('activatable'))
 
+        self.assertEqual('Commit all changes',
+                         dlg._commit_all_files_radio.get_label())
+        self.assertTrue(dlg._commit_all_files_radio.get_property('sensitive'))
+        self.assertTrue(dlg._commit_selected_radio.get_property('sensitive'))
+
     def test_pending(self):
         tree = self.make_branch_and_tree('tree')
         rev_id1 = tree.commit('one')
@@ -233,6 +238,11 @@
         values = [(r[0], r[1], r[2], r[3]) for r in dlg._pending_store]
         self.assertEqual([(rev_id2, '2007-10-01', 'Joe Foo', 'two')], values)
 
+        self.assertEqual('Commit all changes*',
+                         dlg._commit_all_files_radio.get_label())
+        self.assertFalse(dlg._commit_all_files_radio.get_property('sensitive'))
+        self.assertFalse(dlg._commit_selected_radio.get_property('sensitive'))
+
     def test_pending_multiple(self):
         tree = self.make_branch_and_tree('tree')
         rev_id1 = tree.commit('one')
@@ -421,6 +431,20 @@
 
         self.assertEqual('Diff for All Files', dlg._diff_label.get_text())
 
+    def test_commit_partial_toggle(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/a', 'tree/b'])
+        tree.add(['a', 'b'], ['a-id', 'b-id'])
+
+        dlg = commit.CommitDialog(tree)
+        checked_col = dlg._treeview_files.get_column(0)
+        self.assertFalse(checked_col.get_property('visible'))
+        self.assertTrue(dlg._commit_all_changes)
+
+        dlg._commit_selected_radio.set_active(True)
+        self.assertTrue(checked_col.get_property('visible'))
+        self.assertFalse(dlg._commit_all_changes)
+
     def test_file_selection(self):
         """Several things should happen when a file has been selected."""
         tree = self.make_branch_and_tree('tree')
@@ -585,6 +609,7 @@
         dlg = commit.CommitDialog(tree)
         self.assertEqual((['a', 'b'], []), dlg._get_specific_files())
 
+        dlg._commit_selected_radio.set_active(True)
         dlg._toggle_commit(None, 0, dlg._files_store)
         self.assertEqual(([], []), dlg._get_specific_files())
 
@@ -598,6 +623,7 @@
         tree.add(['a_file', 'b_dir'], ['1a-id', '0b-id'])
 
         dlg = commit.CommitDialog(tree)
+        dlg._commit_selected_radio.set_active(True)
         self.assertEqual((['a_file', 'b_dir'], []), dlg._get_specific_files())
 
         dlg._treeview_files.set_cursor((1,))
@@ -804,6 +830,7 @@
         tree.add(['a', 'b'], ['a-id', 'b-id'])
 
         dlg = commit.CommitDialog(tree)
+        dlg._commit_selected_radio.set_active(True) # enable partial
         dlg._toggle_commit(None, 2, dlg._files_store) # unset 'b'
 
         dlg._set_global_commit_message('Committing just "a"\n')
@@ -818,6 +845,32 @@
                                        if path] # Ignore the root entry
         self.assertEqual([('a', 'a-id')], entries)
 
+    def test_commit_partial_no_partial(self):
+        """Ignore the checkboxes if committing all files."""
+        tree = self.make_branch_and_tree('tree')
+        rev_id1 = tree.commit('one')
+        self.build_tree(['tree/a', 'tree/b'])
+        tree.add(['a', 'b'], ['a-id', 'b-id'])
+
+        dlg = commit.CommitDialog(tree)
+        dlg._commit_selected_radio.set_active(True) # enable partial
+        dlg._toggle_commit(None, 2, dlg._files_store) # unset 'b'
+
+        # Switch back to committing all changes
+        dlg._commit_all_files_radio.set_active(True)
+
+        dlg._set_global_commit_message('Committing everything\n')
+        dlg._do_commit()
+
+        rev_id2 = dlg.committed_revision_id
+        self.assertIsNot(None, rev_id2)
+        self.assertEqual(rev_id2, tree.last_revision())
+
+        rt = tree.branch.repository.revision_tree(rev_id2)
+        entries = [(path, ie.file_id) for path, ie in rt.iter_entries_by_dir()
+                                       if path] # Ignore the root entry
+        self.assertEqual([('a', 'a-id'), ('b', 'b-id')], entries)
+
     def test_commit_no_messages(self):
         tree = self.make_branch_and_tree('tree')
         rev_id1 = tree.commit('one')
@@ -875,6 +928,7 @@
         tree.add(['a', 'b'], ['a-id', 'b-id'])
 
         dlg = commit.CommitDialog(tree)
+        dlg._commit_selected_radio.set_active(True) # enable partial
         dlg._treeview_files.set_cursor((1,))
         dlg._set_file_commit_message('Message for A\n')
         dlg._treeview_files.set_cursor((2,))

